Struct rkyv::time::ArchivedDuration [−][src]
pub struct ArchivedDuration { /* fields omitted */ }Expand description
An archived Duration.
Implementations
Returns the number of whole seconds contained by this
ArchivedDuration.
The returned value does not include the fractional (nanosecond) part of the duration, which
can be obtained using subsec_nanos.
Returns the fractional part of this ArchivedDuration, in whole milliseconds.
This method does not return the length of the duration when represented by milliseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one thousand).
Returns the fractional part of this ArchivedDuration, in whole microseconds.
This method does not return the length of the duration when represented by microseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one million).
Returns the fractional part of this Duration, in nanoseconds.
This method does not return the length of the duration when represented by nanoseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one billion).
Returns the total number of whole milliseconds contained by this ArchivedDuration.
Returns the total number of whole microseconds contained by this ArchivedDuration.
Returns the total number of nanoseconds contained by this ArchivedDuration.
Returns the number of seconds contained by this ArchivedDuration as f64.
The returned value does include the fractional (nanosecond) part of the duration.
Returns the number of seconds contained by this ArchivedDuration as f32.
The returned value does include the fractional (nanosecond) part of the duration.